@@ -114,8 +114,11 @@ class DateTimeParser(object):
 
     # TODO: since we support more than ISO 8601, we should rename this function
     # IDEA: break into multiple functions
-    def parse_iso(self, datetime_string):
-        # TODO: add a flag to normalize whitespace (useful in logs, ref issue #421)
+    def parse_iso(self, datetime_string, normalize_whitespace=False):
+
+        if normalize_whitespace:
+            datetime_string = re.sub(r"\s+", " ", datetime_string.strip())
+
         has_space_divider = " " in datetime_string
         has_t_divider = "T" in datetime_string
 
@@ -213,7 +216,10 @@ class DateTimeParser(object):
 
         return self._parse_multiformat(datetime_string, formats)
 
-    def parse(self, datetime_string, fmt):
+    def parse(self, datetime_string, fmt, normalize_whitespace=False):
+
+        if normalize_whitespace:
+            datetime_string = re.sub(r"\s+", " ", datetime_string)
 
         if isinstance(fmt, list):
             return self._parse_multiformat(datetime_string, fmt)
